==> beast-0.6.1.tar.gz: beast-0.6.1/tests/testplugin.gen-idl.h <==

/*-------- begin ../sfi/sfidl generated code --------*/



#include <bse/bsecxxplugin.h>


/* enum prototypes */
namespace Namespace {
#define NAMESPACE_TYPE_FUNKYNESS_TYPE		BSE_CXX_DECLARED_ENUM_TYPE (Namespace, FunkynessType)


/* choice prototypes */
static inline SfiChoiceValues FunkynessType_choice_values();


/* record prototypes */
class TestRecord;
typedef Sfi::RecordHandle<TestRecord> TestRecordHandle;
#define NAMESPACE_TYPE_TEST_RECORD		BSE_CXX_DECLARED_RECORD_TYPE (Namespace, TestRecord)


/* sequence prototypes */
class TestSequence;
#define NAMESPACE_TYPE_TEST_SEQUENCE		BSE_CXX_DECLARED_SEQUENCE_TYPE (Namespace, TestSequence)


/* class prototypes */
class TestObjectBase;
class TestObject;
#define NAMESPACE_TYPE_TEST_OBJECT		BSE_CXX_DECLARED_CLASS_TYPE (Namespace, TestObject)
#define NAMESPACE_IS_TEST_OBJECT(o) (::Bse::CxxBase::instance_is_a (o, NAMESPACE_TYPE_TEST_OBJECT))


/* enum definitions */
enum FunkynessType {
  REALLY_FUNKY = 0,
  MODERATELY_FUNKY = 1,
  NON_FUNKY = 42,
};


/* sequence definitions */
class TestSequence : public Sfi::Sequence< ::Namespace::TestRecordHandle > {
public:
  TestSequence (unsigned int n = 0) : Sfi::Sequence< ::Namespace::TestRecordHandle > (n) {}
  static inline ::Namespace::TestSequence from_seq (SfiSeq *seq);
  static inline SfiSeq *to_seq (const ::Namespace::TestSequence & seq);
  static inline ::Namespace::TestSequence value_get_boxed (const GValue *value);
  static inline void value_set_boxed (GValue *value, const ::Namespace::TestSequence & self);
  static inline const char* options   () { return ""; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestSequence"; }
  static inline GParamSpec* get_element ();
};



/* record definitions */
class TestRecord : public ::Sfi::GNewable {
public:
  Sfi::Int i;
  Sfi::String str;
  ::Namespace::FunkynessType funky;
  static inline ::Namespace::TestRecordHandle from_rec (SfiRec *rec);
  static inline SfiRec *to_rec (const ::Namespace::TestRecordHandle & ptr);
  static inline ::Namespace::TestRecordHandle value_get_boxed (const GValue *value);
  static inline void value_set_boxed (GValue *value, const ::Namespace::TestRecordHandle & self);
  static inline const char* options   () { return ""; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestRecord"; }
  static inline SfiRecFields get_fields ();
};



/* class definitions */
BSE_CXX_DECLARE_CLASS (TestObject);
class TestObjectBase : public ::Bse::Effect {
public:
  static inline const unsigned char* pixstream () { return NULL; }
  static void               class_init (::Bse::CxxBaseClass *klass);
  static inline const char* options   () { return ""; }
  static inline const char* category  () { static const char *c = NULL; const char *category = "/Test/Plugin"; 
    if (!c && category[0]) c = g_intern_strconcat ("/Modules", category[0] == '/' ? "" : "/", category, NULL);
    return c; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestObject"; }
protected:
  Sfi::Int aninteger;
  ::Namespace::TestRecordHandle r;
  ::Namespace::TestSequence s;
  Sfi::BBlock bb;
  Sfi::FBlock fb;
  Sfi::Rec rr;
  ::Bse::Effect* ef;
  BseItem* it;
protected:
  enum TestObjectPropertyID {
    PROP_ANINTEGER = 1,
    PROP_R,
    PROP_S,
    PROP_BB,
    PROP_FB,
    PROP_RR,
    PROP_EF,
    PROP_IT,
  };
public:
  void set_property (guint prop_id, const ::Bse::Value &value, GParamSpec *pspec)
  {
    switch (prop_id) {
    case PROP_ANINTEGER:
      aninteger = sfi_value_get_int (&value);
    break;
    case PROP_R:
      r = ::Namespace::TestRecord::value_get_boxed (&value);
    break;
    case PROP_S:
      s = ::Namespace::TestSequence::value_get_boxed (&value);
    break;
    case PROP_BB:
      bb = ::Sfi::BBlock::value_get_bblock (&value);
    break;
    case PROP_FB:
      fb = ::Sfi::FBlock::value_get_fblock (&value);
    break;
    case PROP_RR:
      rr = ::Sfi::Rec::value_get_rec (&value);
    break;
    case PROP_EF:
      ef = (::Bse::Effect*) ::Bse::CxxBase::value_get_object< ::Bse::EffectBase* > (&value);
    break;
    case PROP_IT:
      it = ::Bse::CxxBase::value_get_gobject< BseItem> (&value);
    break;
    };
    property_changed ((TestObjectPropertyID) prop_id);
    update_modules();
    switch (prop_id) {
    default: ;
    };
  }
  void get_property (guint prop_id, ::Bse::Value &value, GParamSpec *pspec)
  {
    switch (prop_id) {
    case PROP_ANINTEGER:
      sfi_value_set_int (&value, aninteger);
    break;
    case PROP_R:
      ::Namespace::TestRecord::value_set_boxed (&value, r);
    break;
    case PROP_S:
      ::Namespace::TestSequence::value_set_boxed (&value, s);
    break;
    case PROP_BB:
      ::Sfi::BBlock::value_set_bblock (&value, bb);
    break;
    case PROP_FB:
      ::Sfi::FBlock::value_set_fblock (&value, fb);
    break;
    case PROP_RR:
      ::Sfi::Rec::value_set_rec (&value, rr);
    break;
    case PROP_EF:
      ::Bse::CxxBase::value_set_casted< Bse::Effect, Bse::EffectBase> (&value, ef);
    break;
    case PROP_IT:
      ::Bse::CxxBase::value_set_gobject (&value, it);
    break;
    };
  }
private:
  static struct StaticData {
    int dummy;
  } static_data;
protected:
  virtual void property_changed (TestObjectPropertyID) {}
  virtual ~TestObjectBase ()
  {
  }
public:
};


/* sequence type declarations */
BSE_CXX_DECLARE_SEQUENCE (TestSequence);



/* record type declarations */
BSE_CXX_DECLARE_RECORD (TestRecord);



/* procedure prototypes */
namespace Procedure {
class test_exception;
#define NAMESPACE_TYPE_TEST_EXCEPTION		BSE_CXX_DECLARED_PROC_TYPE (Namespace, test_exception)
} // Procedure



/* enum implementations */
BSE_CXX_DECLARE_ENUM (FunkynessType, "NamespaceFunkynessType", 3,
  *v++ = ::Bse::EnumValue (REALLY_FUNKY, "NAMESPACE_REALLY_FUNKY", "namespace-really-funky" );
  *v++ = ::Bse::EnumValue (MODERATELY_FUNKY, "NAMESPACE_MODERATELY_FUNKY", "namespace-moderately-funky" );
  *v++ = ::Bse::EnumValue (NON_FUNKY, "NAMESPACE_NON_FUNKY", "No Funk At All" );
);


/* choice implementations */
static inline SfiChoiceValues
FunkynessType_choice_values()
{
  static SfiChoiceValue values[3];
  static const SfiChoiceValues choice_values = {
    G_N_ELEMENTS (values), values,
  };
  if (!values[0].choice_ident)
    {
      values[0].choice_ident = "NAMESPACE_REALLY_FUNKY";
      values[0].choice_label = "namespace-really-funky";
      values[0].choice_blurb = "";
      values[1].choice_ident = "NAMESPACE_MODERATELY_FUNKY";
      values[1].choice_label = "namespace-moderately-funky";
      values[1].choice_blurb = "";
      values[2].choice_ident = "NAMESPACE_NON_FUNKY";
      values[2].choice_label = "No Funk At All";
      values[2].choice_blurb = "";
  }
  return choice_values;
}



/* record implementations */
::Namespace::TestRecordHandle
TestRecord::from_rec (SfiRec *sfi_rec)
{
  GValue *element;

  if (!sfi_rec)
    return Sfi::INIT_NULL;

  ::Namespace::TestRecordHandle rec = Sfi::INIT_DEFAULT;
  element = sfi_rec_get (sfi_rec, "i");
  if (element)
    rec->i = sfi_value_get_int (element);
  element = sfi_rec_get (sfi_rec, "str");
  if (element)
    rec->str = ::Sfi::String::value_get_string (element);
  element = sfi_rec_get (sfi_rec, "funky");
  if (element)
    rec->funky = (::Namespace::FunkynessType) sfi_value_get_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS1 (element);
  return rec;
}

SfiRec *
TestRecord::to_rec (const ::Namespace::TestRecordHandle & rec)
{
  SfiRec *sfi_rec;
  GValue *element;

  if (!rec)
    return NULL;

  sfi_rec = sfi_rec_new ();
  element = sfi_rec_forced_get (sfi_rec, "i", SFI_TYPE_INT);
  sfi_value_set_int (element, rec->i);
  element = sfi_rec_forced_get (sfi_rec, "str", SFI_TYPE_STRING);
  ::Sfi::String::value_set_string (element, rec->str);
  element = sfi_rec_forced_get (sfi_rec, "funky", SFI_TYPE_CHOICE);
  sfi_value_set_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS2 (element, rec->funky);
  return sfi_rec;
}

::Namespace::TestRecordHandle
TestRecord::value_get_boxed (const GValue *value)
{
  return ::Namespace::TestRecordHandle::value_get_boxed (value);
}

void
TestRecord::value_set_boxed (GValue *value, const ::Namespace::TestRecordHandle & self)
{
  ::Namespace::TestRecordHandle::value_set_boxed (value, self);
}

SfiRecFields
TestRecord::get_fields()
{
  static SfiRecFields rfields = { 0, NULL };
  if (!rfields.n_fields)
    {
      static GParamSpec *fields[3 + 1];
      rfields.n_fields = 3;
      fields[0] = sfidl_pspec_Int_default (NULL,"i");
      fields[1] = sfidl_pspec_String_default (NULL,"str");
      fields[2] = sfidl_pspec_Choice_default (NULL, "funky", Namespace::FunkynessType_choice_values());
      rfields.fields = fields;
    }
  return rfields;
}


/* sequence implementations */
::Namespace::TestSequence
TestSequence::from_seq (SfiSeq *sfi_seq)
{
  ::Namespace::TestSequence cseq;
  guint i, length;

  if (!sfi_seq)
    return cseq;

  length = sfi_seq_length (sfi_seq);
  cseq.resize (length);
  for (i = 0; i < length; i++)
    {
      GValue *element = sfi_seq_get (sfi_seq, i);
      cseq[i] = ::Namespace::TestRecord::value_get_boxed (element);
    }
  return cseq;
}

SfiSeq *
TestSequence::to_seq (const ::Namespace::TestSequence & cseq)
{
  SfiSeq *sfi_seq = sfi_seq_new ();
  for (guint i = 0; i < cseq.length(); i++)
    {
      GValue *element = sfi_seq_append_empty (sfi_seq, SFI_TYPE_REC);
      ::Namespace::TestRecord::value_set_boxed (element, cseq[i]);
    }
  return sfi_seq;
}

::Namespace::TestSequence
TestSequence::value_get_boxed (const GValue *value)
{
  return ::Sfi::cxx_value_get_boxed_sequence< TestSequence> (value);
}

void
TestSequence::value_set_boxed (GValue *value, const ::Namespace::TestSequence & self)
{
  ::Sfi::cxx_value_set_boxed_sequence< TestSequence> (value, self);
}

GParamSpec*
TestSequence::get_element()
{
  static GParamSpec *element = NULL;
  if (!element)
    element = sfidl_pspec_Record_default (NULL, "tr", Namespace::TestRecord::get_fields());
  return element;
}



/* class implementations */
void
TestObjectBase::class_init (::Bse::CxxBaseClass *klass)
{
  klass->add_param (PROP_ANINTEGER, sfidl_pspec_Int_default (NULL,"aninteger"));
  klass->add_param (PROP_R, sfidl_pspec_BoxedRec_default (NULL, "r", NAMESPACE_TYPE_TEST_RECORD));
  klass->add_param (PROP_S, sfidl_pspec_BoxedSeq_default (NULL, "s", NAMESPACE_TYPE_TEST_SEQUENCE));
  klass->add_param (PROP_BB, sfidl_pspec_BBlock_default (NULL,"bb"));
  klass->add_param (PROP_FB, sfidl_pspec_FBlock_default (NULL,"fb"));
  klass->add_param (PROP_RR, sfidl_pspec_Rec_default (NULL, "rr", ));
  klass->add_param (PROP_EF, sfidl_pspec_Object_default (NULL, "ef", BSE_TYPE_EFFECT));
  klass->add_param (PROP_IT, sfidl_pspec_Object_default (NULL, "it", BSE_TYPE_ITEM));
}


/* procedure implementations */
namespace Procedure {
BSE_CXX_DECLARE_PROC (test_exception);
class test_exception {
public:
  static inline const unsigned char* pixstream () { return NULL; }
  static inline const char* options   () { return ""; }
  static inline const char* category  () { static const char *c = NULL; 
    const char *root_category = "", *category = "/Toys/Test Exception";
    if (!c && category[0]) c = g_intern_strconcat (root_category && root_category[0] ? root_category : "/Proc",
                                    category[0] == '/' ? "" : "/", category, NULL);
    return c; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "namespace-test-exception"; }
  static Sfi::Int exec (Sfi::Int i, ::Namespace::TestObject* o, Sfi::Int bar, ::Namespace::FunkynessType ft);
  static BseErrorType marshal (BseProcedureClass *procedure,
                               const GValue      *in_values,
                               GValue            *out_values)
  {
    try {
      Sfi::Int __return_value =
        exec (
              sfi_value_get_int (in_values + 0),
              (::Namespace::TestObject*) ::Bse::CxxBase::value_get_object< ::Namespace::TestObjectBase* > (in_values + 1),
              sfi_value_get_int (in_values + 2),
              (::Namespace::FunkynessType) sfi_value_get_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS1 (in_values + 3) 
             );
      sfi_value_set_int (out_values, __return_value);
    } catch (std::exception &e) {
      sfi_debug ("%s: %s", "test_exception", e.what());
      return BSE_ERROR_PROC_EXECUTION;
    } catch (...) {
      sfi_debug ("%s: %s", "test_exception", "unknown exception");
      return BSE_ERROR_PROC_EXECUTION;
    }
    return BSE_ERROR_NONE;
  }
  static void init (BseProcedureClass *proc,
                    GParamSpec       **in_pspecs,
                    GParamSpec       **out_pspecs)
  {
    *(in_pspecs++) = sfidl_pspec_Int_default (NULL,"i");
    *(in_pspecs++) = sfidl_pspec_Object_default (NULL, "o", NAMESPACE_TYPE_TEST_OBJECT);
    *(in_pspecs++) = sfidl_pspec_Int_default (NULL,"bar");
    *(in_pspecs++) = sfidl_pspec_GEnum_default (NULL, "ft", NAMESPACE_TYPE_FUNKYNESS_TYPE);
    *(out_pspecs++) = sfidl_pspec_Int_default (NULL,"result");
  }
};
} // Procedure



/*  type registrations */
} // Namespace

/*-------- end ../sfi/sfidl generated code --------*/

==> beast_0.6.2.orig.tar.gz: beast-0.6.2/tests/testplugin.gen-idl.h <==

/*-------- begin ../sfi/sfidl generated code --------*/



#include <bse/bsecxxplugin.h>


/* enum prototypes */
namespace Namespace {
#define NAMESPACE_TYPE_FUNKYNESS_TYPE		BSE_CXX_DECLARED_ENUM_TYPE (Namespace, FunkynessType)


/* choice prototypes */
static inline SfiChoiceValues FunkynessType_choice_values();


/* record prototypes */
class TestRecord;
typedef Sfi::RecordHandle<TestRecord> TestRecordHandle;
#define NAMESPACE_TYPE_TEST_RECORD		BSE_CXX_DECLARED_RECORD_TYPE (Namespace, TestRecord)


/* sequence prototypes */
class TestSequence;
#define NAMESPACE_TYPE_TEST_SEQUENCE		BSE_CXX_DECLARED_SEQUENCE_TYPE (Namespace, TestSequence)


/* class prototypes */
class TestObjectBase;
class TestObject;
#define NAMESPACE_TYPE_TEST_OBJECT		BSE_CXX_DECLARED_CLASS_TYPE (Namespace, TestObject)
#define NAMESPACE_IS_TEST_OBJECT(o) (::Bse::CxxBase::instance_is_a (o, NAMESPACE_TYPE_TEST_OBJECT))


/* enum definitions */
enum FunkynessType {
  REALLY_FUNKY = 0,
  MODERATELY_FUNKY = 1,
  NON_FUNKY = 42,
};


/* sequence definitions */
class TestSequence : public Sfi::Sequence< ::Namespace::TestRecordHandle > {
public:
  TestSequence (unsigned int n = 0) : Sfi::Sequence< ::Namespace::TestRecordHandle > (n) {}
  static inline ::Namespace::TestSequence from_seq (SfiSeq *seq);
  static inline SfiSeq *to_seq (const ::Namespace::TestSequence & seq);
  static inline ::Namespace::TestSequence value_get_boxed (const GValue *value);
  static inline void value_set_boxed (GValue *value, const ::Namespace::TestSequence & self);
  static inline const char* options   () { return ""; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestSequence"; }
  static inline GParamSpec* get_element ();
};



/* record definitions */
class TestRecord : public ::Sfi::GNewable {
public:
  Sfi::Int i;
  Sfi::String str;
  ::Namespace::FunkynessType funky;
  static inline ::Namespace::TestRecordHandle from_rec (SfiRec *rec);
  static inline SfiRec *to_rec (const ::Namespace::TestRecordHandle & ptr);
  static inline ::Namespace::TestRecordHandle value_get_boxed (const GValue *value);
  static inline void value_set_boxed (GValue *value, const ::Namespace::TestRecordHandle & self);
  static inline const char* options   () { return ""; }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestRecord"; }
  static inline SfiRecFields get_fields ();
};



/* class definitions */
BSE_CXX_DECLARE_CLASS (TestObject);
class TestObjectBase : public ::Bse::Effect {
public:
  static inline const unsigned char* pixstream () { return NULL; }
  static void               class_init (::Bse::CxxBaseClass *klass);
  static inline const char* options   () { return ""; }
  static inline const char* category  () { static const char *c = NULL;
    return c ? c : c = sfi_category_concat ("/Modules", "/Test/Plugin"); }
  static inline const char* i18n_category  () { static const char *c = NULL;
    return c ? c : c = sfi_category_concat ("/Modules", "/Test/Plugin"); }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "NamespaceTestObject"; }
protected:
  Sfi::Int aninteger;
  ::Namespace::TestRecordHandle r;
  ::Namespace::TestSequence s;
  Sfi::BBlock bb;
  Sfi::FBlock fb;
  Sfi::Rec rr;
  ::Bse::Effect* ef;
  BseItem* it;
protected:
  enum TestObjectPropertyID {
    PROP_ANINTEGER = 1,
    PROP_R,
    PROP_S,
    PROP_BB,
    PROP_FB,
    PROP_RR,
    PROP_EF,
    PROP_IT,
  };
public:
  void set_property (guint prop_id, const ::Bse::Value &value, GParamSpec *pspec)
  {
    switch (prop_id) {
    case PROP_ANINTEGER:
      aninteger = sfi_value_get_int (&value);
    break;
    case PROP_R:
      r = ::Namespace::TestRecord::value_get_boxed (&value);
    break;
    case PROP_S:
      s = ::Namespace::TestSequence::value_get_boxed (&value);
    break;
    case PROP_BB:
      bb = ::Sfi::BBlock::value_get_bblock (&value);
    break;
    case PROP_FB:
      fb = ::Sfi::FBlock::value_get_fblock (&value);
    break;
    case PROP_RR:
      rr = ::Sfi::Rec::value_get_rec (&value);
    break;
    case PROP_EF:
      ef = (::Bse::Effect*) ::Bse::CxxBase::value_get_object< ::Bse::EffectBase* > (&value);
    break;
    case PROP_IT:
      it = ::Bse::CxxBase::value_get_gobject< BseItem> (&value);
    break;
    };
    property_changed ((TestObjectPropertyID) prop_id);
    update_modules();
    switch (prop_id) {
    default: ;
    };
  }
  void get_property (guint prop_id, ::Bse::Value &value, GParamSpec *pspec)
  {
    switch (prop_id) {
    case PROP_ANINTEGER:
      sfi_value_set_int (&value, aninteger);
    break;
    case PROP_R:
      ::Namespace::TestRecord::value_set_boxed (&value, r);
    break;
    case PROP_S:
      ::Namespace::TestSequence::value_set_boxed (&value, s);
    break;
    case PROP_BB:
      ::Sfi::BBlock::value_set_bblock (&value, bb);
    break;
    case PROP_FB:
      ::Sfi::FBlock::value_set_fblock (&value, fb);
    break;
    case PROP_RR:
      ::Sfi::Rec::value_set_rec (&value, rr);
    break;
    case PROP_EF:
      ::Bse::CxxBase::value_set_casted< Bse::Effect, Bse::EffectBase> (&value, ef);
    break;
    case PROP_IT:
      ::Bse::CxxBase::value_set_gobject (&value, it);
    break;
    };
  }
private:
  static struct StaticData {
    int dummy;
  } static_data;
protected:
  virtual void property_changed (TestObjectPropertyID) {}
  virtual ~TestObjectBase ()
  {
  }
public:
};


/* sequence type declarations */
BSE_CXX_DECLARE_SEQUENCE (TestSequence);



/* record type declarations */
BSE_CXX_DECLARE_RECORD (TestRecord);



/* procedure prototypes */
namespace Procedure {
class test_exception;
#define NAMESPACE_TYPE_TEST_EXCEPTION		BSE_CXX_DECLARED_PROC_TYPE (Namespace, test_exception)
} // Procedure



/* enum implementations */
BSE_CXX_DECLARE_ENUM (FunkynessType, "NamespaceFunkynessType", 3,
  *v++ = ::Bse::EnumValue (REALLY_FUNKY, "NAMESPACE_REALLY_FUNKY", "namespace-really-funky" );
  *v++ = ::Bse::EnumValue (MODERATELY_FUNKY, "NAMESPACE_MODERATELY_FUNKY", "namespace-moderately-funky" );
  *v++ = ::Bse::EnumValue (NON_FUNKY, "NAMESPACE_NON_FUNKY", "No Funk At All" );
);


/* choice implementations */
static inline SfiChoiceValues
FunkynessType_choice_values()
{
  static SfiChoiceValue values[3];
  static const SfiChoiceValues choice_values = {
    G_N_ELEMENTS (values), values,
  };
  if (!values[0].choice_ident)
    {
      values[0].choice_ident = "NAMESPACE_REALLY_FUNKY";
      values[0].choice_label = "namespace-really-funky";
      values[0].choice_blurb = "";
      values[1].choice_ident = "NAMESPACE_MODERATELY_FUNKY";
      values[1].choice_label = "namespace-moderately-funky";
      values[1].choice_blurb = "";
      values[2].choice_ident = "NAMESPACE_NON_FUNKY";
      values[2].choice_label = "No Funk At All";
      values[2].choice_blurb = "";
  }
  return choice_values;
}



/* record implementations */
::Namespace::TestRecordHandle
TestRecord::from_rec (SfiRec *sfi_rec)
{
  GValue *element;

  if (!sfi_rec)
    return Sfi::INIT_NULL;

  ::Namespace::TestRecordHandle rec = Sfi::INIT_DEFAULT;
  element = sfi_rec_get (sfi_rec, "i");
  if (element)
    rec->i = sfi_value_get_int (element);
  element = sfi_rec_get (sfi_rec, "str");
  if (element)
    rec->str = ::Sfi::String::value_get_string (element);
  element = sfi_rec_get (sfi_rec, "funky");
  if (element)
    rec->funky = (::Namespace::FunkynessType) sfi_value_get_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS1 (element);
  return rec;
}

SfiRec *
TestRecord::to_rec (const ::Namespace::TestRecordHandle & rec)
{
  SfiRec *sfi_rec;
  GValue *element;

  if (!rec)
    return NULL;

  sfi_rec = sfi_rec_new ();
  element = sfi_rec_forced_get (sfi_rec, "i", SFI_TYPE_INT);
  sfi_value_set_int (element, rec->i);
  element = sfi_rec_forced_get (sfi_rec, "str", SFI_TYPE_STRING);
  ::Sfi::String::value_set_string (element, rec->str);
  element = sfi_rec_forced_get (sfi_rec, "funky", SFI_TYPE_CHOICE);
  sfi_value_set_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS2 (element, rec->funky);
  return sfi_rec;
}

::Namespace::TestRecordHandle
TestRecord::value_get_boxed (const GValue *value)
{
  return ::Namespace::TestRecordHandle::value_get_boxed (value);
}

void
TestRecord::value_set_boxed (GValue *value, const ::Namespace::TestRecordHandle & self)
{
  ::Namespace::TestRecordHandle::value_set_boxed (value, self);
}

SfiRecFields
TestRecord::get_fields()
{
  static SfiRecFields rfields = { 0, NULL };
  if (!rfields.n_fields)
    {
      static GParamSpec *fields[3 + 1];
      rfields.n_fields = 3;
      fields[0] = sfidl_pspec_Int_default (NULL,"i");
      fields[1] = sfidl_pspec_String_default (NULL,"str");
      fields[2] = sfidl_pspec_Choice_default (NULL, "funky", Namespace::FunkynessType_choice_values());
      rfields.fields = fields;
    }
  return rfields;
}


/* sequence implementations */
::Namespace::TestSequence
TestSequence::from_seq (SfiSeq *sfi_seq)
{
  ::Namespace::TestSequence cseq;
  guint i, length;

  if (!sfi_seq)
    return cseq;

  length = sfi_seq_length (sfi_seq);
  cseq.resize (length);
  for (i = 0; i < length; i++)
    {
      GValue *element = sfi_seq_get (sfi_seq, i);
      cseq[i] = ::Namespace::TestRecord::value_get_boxed (element);
    }
  return cseq;
}

SfiSeq *
TestSequence::to_seq (const ::Namespace::TestSequence & cseq)
{
  SfiSeq *sfi_seq = sfi_seq_new ();
  for (guint i = 0; i < cseq.length(); i++)
    {
      GValue *element = sfi_seq_append_empty (sfi_seq, SFI_TYPE_REC);
      ::Namespace::TestRecord::value_set_boxed (element, cseq[i]);
    }
  return sfi_seq;
}

::Namespace::TestSequence
TestSequence::value_get_boxed (const GValue *value)
{
  return ::Sfi::cxx_value_get_boxed_sequence< TestSequence> (value);
}

void
TestSequence::value_set_boxed (GValue *value, const ::Namespace::TestSequence & self)
{
  ::Sfi::cxx_value_set_boxed_sequence< TestSequence> (value, self);
}

GParamSpec*
TestSequence::get_element()
{
  static GParamSpec *element = NULL;
  if (!element)
    element = sfidl_pspec_Record_default (NULL, "tr", Namespace::TestRecord::get_fields());
  return element;
}



/* class implementations */
void
TestObjectBase::class_init (::Bse::CxxBaseClass *klass)
{
  klass->add_param (PROP_ANINTEGER, sfidl_pspec_Int_default (NULL,"aninteger"));
  klass->add_param (PROP_R, sfidl_pspec_BoxedRec_default (NULL, "r", NAMESPACE_TYPE_TEST_RECORD));
  klass->add_param (PROP_S, sfidl_pspec_BoxedSeq_default (NULL, "s", NAMESPACE_TYPE_TEST_SEQUENCE));
  klass->add_param (PROP_BB, sfidl_pspec_BBlock_default (NULL,"bb"));
  klass->add_param (PROP_FB, sfidl_pspec_FBlock_default (NULL,"fb"));
  klass->add_param (PROP_RR, sfidl_pspec_Rec_default (NULL, "rr", ));
  klass->add_param (PROP_EF, sfidl_pspec_Object_default (NULL, "ef", BSE_TYPE_EFFECT));
  klass->add_param (PROP_IT, sfidl_pspec_Object_default (NULL, "it", BSE_TYPE_ITEM));
}


/* procedure implementations */
namespace Procedure {
BSE_CXX_DECLARE_PROC (test_exception);
class test_exception {
public:
  static inline const unsigned char* pixstream () { return NULL; }
  static inline const char* options   () { return ""; }
  static inline const char* category  () { static const char *c = NULL;
    return c ? c : c = sfi_category_concat ("/Proc", "/Toys/Test Exception"); }
  static inline const char* i18n_category  () { static const char *c = NULL;
    return c ? c : c = sfi_category_concat ("/Proc", "/Toys/Test Exception"); }
  static inline const char* blurb     () { return ""; }
  static inline const char* authors   () { return ""; }
  static inline const char* license   () { return ""; }
  static inline const char* type_name () { return "namespace-test-exception"; }
  static Sfi::Int exec (Sfi::Int i, ::Namespace::TestObject* o, Sfi::Int bar, ::Namespace::FunkynessType ft);
  static BseErrorType marshal (BseProcedureClass *procedure,
                               const GValue      *in_values,
                               GValue            *out_values)
  {
    try {
      Sfi::Int __return_value =
        exec (
              sfi_value_get_int (in_values + 0),
              (::Namespace::TestObject*) ::Bse::CxxBase::value_get_object< ::Namespace::TestObjectBase* > (in_values + 1),
              sfi_value_get_int (in_values + 2),
              (::Namespace::FunkynessType) sfi_value_get_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS1 (in_values + 3) 
             );
      sfi_value_set_int (out_values, __return_value);
    } catch (std::exception &e) {
      sfi_diag ("%s: %s", "test_exception", e.what());
      return BSE_ERROR_PROC_EXECUTION;
    } catch (...) {
      sfi_diag ("%s: %s", "test_exception", "uncaught exception");
      return BSE_ERROR_PROC_EXECUTION;
    }
    return BSE_ERROR_NONE;
  }
  static void init (BseProcedureClass *proc,
                    GParamSpec       **in_pspecs,
                    GParamSpec       **out_pspecs)
  {
    *(in_pspecs++) = sfidl_pspec_Int_default (NULL,"i");
    *(in_pspecs++) = sfidl_pspec_Object_default (NULL, "o", NAMESPACE_TYPE_TEST_OBJECT);
    *(in_pspecs++) = sfidl_pspec_Int_default (NULL,"bar");
    *(in_pspecs++) = sfidl_pspec_GEnum_default (NULL, "ft", NAMESPACE_TYPE_FUNKYNESS_TYPE);
    *(out_pspecs++) = sfidl_pspec_Int_default (NULL,"result");
  }
};
} // Procedure



/*  type registrations */
} // Namespace

/*-------- end ../sfi/sfidl generated code --------*/
